pub type Result<T> = Result<T, StorageError>;Expand description
A specialized Result type for Azure Storage Blob operations.
Aliased Type
pub enum Result<T> {
Ok(T),
Err(StorageError),
}pub type Result<T> = Result<T, StorageError>;A specialized Result type for Azure Storage Blob operations.
pub enum Result<T> {
Ok(T),
Err(StorageError),
}